@@ -21,8 +21,10 @@ from .config import CredentialProvider, MissingCredentials
 from .ApiResponse import ApiResponse
 from .processing_status import ProcessingStatus
 from .reportTypes import ReportType
+from sp_api.auth import AccessTokenClient
 
 __all__ = [
+    'AccessTokenClient',
     'ReportType',
     'ProcessingStatus',
     'ApiResponse',
